==> tuia-payment-center-api-0.0.30-LZH-20241028.093536-3-sources.jar: cn/tuia/payment/api/constants/RedisKey.java <==
package cn.tuia.payment.api.constants;

import cn.tuia.payment.api.enums.PaymentChannelEnum;

import java.util.Objects;

/**
 * @author lizhiheng
 */
public class RedisKey {
    /**
     * 例子：55502_BANK_MER_PERIOD_1_POOL
     * 55502商户在第1时间段内的子商户池
     * 尽量使用下面这个方法，formatPoolKey，参数不容易传错位置
     */
    private static final String BANK_MER_PERIOD_POOL = "%s_BANK_MER_PERIOD_%s_POOL";

    private static final String BANK_MER_PERIOD_POOL_V2 = "%s_%s_BANK_MER_PERIOD_%s_POOL";
    // 渠道_行业_时段_xxx_商户池_POOL
    private static final String BANK_MER_PERIOD_POOL_V3 = "%s_%s_%s_BANK_MER_PERIOD_%s_POOL";

    private static final String BANK_MER_POOL_ID_SET = "BANK_MER_POOL_ID_SET";


    /**
     * 商户池缓存key
     *
     * @return
     */
    public static String getBankMerPoolIdSet() {
        return BANK_MER_POOL_ID_SET;
    }

    public static String formatPoolKey(String merId, int period) {
        return String.format(BANK_MER_PERIOD_POOL, merId, period);
    }

    /**
     * 自定义商户池
     */
    public static String formatPoolKeyV2(String merId, int period, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return formatPoolKey(merId, period);
        }
        return String.format(BANK_MER_PERIOD_POOL_V2, poolId, merId, period);
    }

    // 通用商户池key
    public static String getMerPoolKey(Integer channel, String type, int period, Long poolId) {
        if (Objects.equals(PaymentChannelEnum.LIANDONG.getCode(), channel) || Objects.equals(PaymentChannelEnum.UNION_PAY.getCode(), channel)) {
            return formatPoolKeyV2(type, period, poolId);
        }
        return String.format(BANK_MER_PERIOD_POOL_V3, channel, type, period, poolId);
    }
}

==> tuia-payment-center-api-0.0.31-LZH-20241107.075538-21-sources.jar: cn/tuia/payment/api/constants/RedisKey.java <==
package cn.tuia.payment.api.constants;

import cn.tuia.payment.api.enums.PaymentChannelEnum;

import java.util.Objects;

/**
 * @author lizhiheng
 */
public class RedisKey {
    /**
     * 例子：55502_BANK_MER_PERIOD_1_POOL
     * 55502商户在第1时间段内的子商户池
     * 尽量使用下面这个方法，formatPoolKey，参数不容易传错位置
     */
    private static final String BANK_MER_PERIOD_POOL = "%s_BANK_MER_PERIOD_%s_POOL";

    private static final String BANK_MER_PERIOD_POOL_V2 = "%s_%s_BANK_MER_PERIOD_%s_POOL";
    // 渠道_行业_时段_xxx_商户池_POOL
    private static final String BANK_MER_PERIOD_POOL_V3 = "%s_%s_%s_BANK_MER_PERIOD_%s_POOL";

    private static final String BANK_MER_POOL_ID_SET = "BANK_MER_POOL_ID_SET";


    /**
     * 商户池缓存key
     *
     * @return
     */
    public static String getBankMerPoolIdSet() {
        return BANK_MER_POOL_ID_SET;
    }

    public static String formatPoolKey(String merId, int period) {
        return String.format(BANK_MER_PERIOD_POOL, merId, period);
    }

    /**
     * 自定义商户池
     */
    public static String formatPoolKeyV2(String merId, int period, Long poolId) {
        if (Objects.isNull(poolId) || Objects.equals(poolId, 0L)) {
            return formatPoolKey(merId, period);
        }
        return String.format(BANK_MER_PERIOD_POOL_V2, poolId, merId, period);
    }

    // 通用商户池key
    public static String getMerPoolKey(Integer channel, String type, int period, Long poolId) {
        if (Objects.equals(PaymentChannelEnum.LIANDONG.getCode(), channel) || Objects.equals(PaymentChannelEnum.UNION_PAY.getCode(), channel)) {
            return formatPoolKeyV2(type, period, poolId);
        }
        return String.format(BANK_MER_PERIOD_POOL_V3, channel, type, period, poolId);
    }

    /**
     * 渠道_限额类型
     */
    public static final String LIMIT_CONFIG_ITEM_KEY = "limit_config_item_%s_%s";

    public static String getLimitConfigItemKey(Integer channel, Integer limitType) {
        return String.format(LIMIT_CONFIG_ITEM_KEY, channel, limitType);
    }
}
